# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.132
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_installer_metadata import AppInstallerMetadata

class TestAppInstallerMetadata(unittest.TestCase):
    """AppInstallerMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppInstallerMetadata:
        """Test AppInstallerMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppInstallerMetadata`
        """
        model = AppInstallerMetadata()
        if include_optional:
            return AppInstallerMetadata(
                community_url = '',
                copyright_markdown = '',
                created_at = '',
                created_by = nuon.models.app/user_token.app.UserToken(
                    created_at = '', 
                    created_by_id = '', 
                    email = '', 
                    expires_at = '', 
                    id = '', 
                    issued_at = '', 
                    issuer = '', 
                    subject = '', 
                    token_type = 'auth0', 
                    updated_at = '', ),
                created_by_id = '',
                demo_url = '',
                description = '',
                documentation_url = '',
                favicon_url = '',
                footer_markdown = '',
                formatted_demo_url = '',
                github_url = '',
                homepage_url = '',
                id = '',
                installer_id = '',
                logo_url = '',
                name = '',
                post_install_markdown = '',
                updated_at = ''
            )
        else:
            return AppInstallerMetadata(
        )
        """

    def testAppInstallerMetadata(self):
        """Test AppInstallerMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.apps_api import AppsApi


class TestAppsApi(unittest.TestCase):
    """AppsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AppsApi()

    def tearDown(self) -> None:
        pass

    def test_create_app(self) -> None:
        """Test case for create_app

        create an app
        """
        pass

    def test_create_app_input_config(self) -> None:
        """Test case for create_app_input_config

        """
        pass

    def test_create_app_installer(self) -> None:
        """Test case for create_app_installer

        create an app installer
        """
        pass

    def test_create_app_runner_config(self) -> None:
        """Test case for create_app_runner_config

        create an app runner config
        """
        pass

    def test_create_app_sandbox_config(self) -> None:
        """Test case for create_app_sandbox_config

        create an app sandbox config
        """
        pass

    def test_delete_app(self) -> None:
        """Test case for delete_app

        delete an app
        """
        pass

    def test_delete_app_installer(self) -> None:
        """Test case for delete_app_installer

        delete an app installer
        """
        pass

    def test_get_app(self) -> None:
        """Test case for get_app

        get an app
        """
        pass

    def test_get_app_input_configs(self) -> None:
        """Test case for get_app_input_configs

        get app input configs
        """
        pass

    def test_get_app_input_latest_config(self) -> None:
        """Test case for get_app_input_latest_config

        get latest app input config
        """
        pass

    def test_get_app_installer(self) -> None:
        """Test case for get_app_installer

        get an app installer
        """
        pass

    def test_get_app_runner_configs(self) -> None:
        """Test case for get_app_runner_configs

        get app runner configs
        """
        pass

    def test_get_app_runner_latest_config(self) -> None:
        """Test case for get_app_runner_latest_config

        get latest app runner config
        """
        pass

    def test_get_app_sandbox_configs(self) -> None:
        """Test case for get_app_sandbox_configs

        get app sandbox configs
        """
        pass

    def test_get_app_sandbox_latest_config(self) -> None:
        """Test case for get_app_sandbox_latest_config

        get latest app sandbox config
        """
        pass

    def test_get_apps(self) -> None:
        """Test case for get_apps

        get all apps for the current org
        """
        pass

    def test_render_app_installer(self) -> None:
        """Test case for render_app_installer

        render an app installer
        """
        pass

    def test_update_app(self) -> None:
        """Test case for update_app

        update an app
        """
        pass

    def test_update_app_installer(self) -> None:
        """Test case for update_app_installer

        update an app installer
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.sandboxes_api import SandboxesApi


class TestSandboxesApi(unittest.TestCase):
    """SandboxesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SandboxesApi()

    def tearDown(self) -> None:
        pass

    def test_get_sandbox(self) -> None:
        """Test case for get_sandbox

        get a sandbox
        """
        pass

    def test_get_sandbox_releases(self) -> None:
        """Test case for get_sandbox_releases

        get sandbox releases
        """
        pass

    def test_get_sandboxes(self) -> None:
        """Test case for get_sandboxes

        get all sandboxes
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.orgs_api import OrgsApi


class TestOrgsApi(unittest.TestCase):
    """OrgsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrgsApi()

    def tearDown(self) -> None:
        pass

    def test_add_user(self) -> None:
        """Test case for add_user

        Add a user to the current org
        """
        pass

    def test_create_org(self) -> None:
        """Test case for create_org

        create a new org
        """
        pass

    def test_delete_org(self) -> None:
        """Test case for delete_org

        Delete an org
        """
        pass

    def test_get_org(self) -> None:
        """Test case for get_org

        Get an org
        """
        pass

    def test_get_orgs(self) -> None:
        """Test case for get_orgs

        Return current user's orgs
        """
        pass

    def test_update_org(self) -> None:
        """Test case for update_org

        Update current org
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from nuon.api.apps_api import AppsApi
from nuon.api.components_api import ComponentsApi
from nuon.api.general_api import GeneralApi
from nuon.api.installers_api import InstallersApi
from nuon.api.installs_api import InstallsApi
from nuon.api.orgs_api import OrgsApi
from nuon.api.releases_api import ReleasesApi
from nuon.api.vcs_api import VcsApi




# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.153
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_app_input_group import AppAppInputGroup

class TestAppAppInputGroup(unittest.TestCase):
    """AppAppInputGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAppInputGroup:
        """Test AppAppInputGroup
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAppInputGroup`
        """
        model = AppAppInputGroup()
        if include_optional:
            return AppAppInputGroup(
                app_input_id = '',
                app_inputs = [
                    nuon.models.app/app_input.app.AppInput(
                        app_input_id = '', 
                        created_at = '', 
                        created_by = nuon.models.app/user_token.app.UserToken(
                            created_at = '', 
                            created_by_id = '', 
                            email = '', 
                            expires_at = '', 
                            id = '', 
                            issued_at = '', 
                            issuer = '', 
                            subject = '', 
                            token_type = 'auth0', 
                            updated_at = '', ), 
                        created_by_id = '', 
                        default = '', 
                        description = '', 
                        display_name = '', 
                        group = nuon.models.app/app_input_group.app.AppInputGroup(
                            app_input_id = '', 
                            created_at = '', 
                            created_by_id = '', 
                            description = '', 
                            display_name = '', 
                            id = '', 
                            is_default = True, 
                            name = '', 
                            org_id = '', 
                            updated_at = '', ), 
                        group_id = '', 
                        id = '', 
                        name = '', 
                        org_id = '', 
                        required = True, 
                        sensitive = True, 
                        updated_at = '', )
                    ],
                created_at = '',
                created_by = nuon.models.app/user_token.app.UserToken(
                    created_at = '', 
                    created_by_id = '', 
                    email = '', 
                    expires_at = '', 
                    id = '', 
                    issued_at = '', 
                    issuer = '', 
                    subject = '', 
                    token_type = 'auth0', 
                    updated_at = '', ),
                created_by_id = '',
                description = '',
                display_name = '',
                id = '',
                is_default = True,
                name = '',
                org_id = '',
                updated_at = ''
            )
        else:
            return AppAppInputGroup(
        )
        """

    def testAppAppInputGroup(self):
        """Test AppAppInputGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.87
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_azure_account import AppAzureAccount

class TestAppAzureAccount(unittest.TestCase):
    """AppAzureAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAzureAccount:
        """Test AppAzureAccount
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAzureAccount`
        """
        model = AppAzureAccount()
        if include_optional:
            return AppAzureAccount(
                created_at = '',
                created_by = nuon.models.app/user_token.app.UserToken(
                    created_at = '', 
                    created_by_id = '', 
                    email = '', 
                    expires_at = '', 
                    id = '', 
                    issued_at = '', 
                    issuer = '', 
                    subject = '', 
                    token_type = 'auth0', 
                    updated_at = '', ),
                created_by_id = '',
                id = '',
                install = nuon.models.app/install.app.Install(
                    app_id = '', 
                    app_runner_config = nuon.models.app/app_runner_config.app.AppRunnerConfig(
                        app_id = '', 
                        app_runner_type = 'aws-ecs', 
                        cloud_platform = 'aws', 
                        created_at = '', 
                        created_by = nuon.models.app/user_token.app.UserToken(
                            created_at = '', 
                            created_by_id = '', 
                            email = '', 
                            expires_at = '', 
                            id = '', 
                            issued_at = '', 
                            issuer = '', 
                            subject = '', 
                            token_type = 'auth0', 
                            updated_at = '', ), 
                        created_by_id = '', 
                        env_vars = {
                            'key' : ''
                            }, 
                        id = '', 
                        org_id = '', 
                        updated_at = '', ), 
                    app_sandbox_config = nuon.models.app/app_sandbox_config.app.AppSandboxConfig(
                        app_id = '', 
                        artifacts = nuon.models.app_app_sandbox_config_artifacts.app_AppSandboxConfig_artifacts(
                            cloudformation_stack_template = '', 
                            deprovision_policy = '', 
                            provision_policy = '', 
                            trust_policy = '', ), 
                        connected_github_vcs_config = nuon.models.app/connected_github_vcs_config.app.ConnectedGithubVCSConfig(
                            branch = '', 
                            component_config_id = '', 
                            component_config_type = '', 
                            created_at = '', 
                            created_by_id = '', 
                            directory = '', 
                            id = '', 
                            repo = '', 
                            repo_name = '', 
                            repo_owner = '', 
                            updated_at = '', 
                            vcs_connection = nuon.models.app/vcs_connection.app.VCSConnection(
                                created_at = '', 
                                created_by_id = '', 
                                github_install_id = '', 
                                id = '', 
                                updated_at = '', 
                                vcs_connection_commit = [
                                    nuon.models.app/vcs_connection_commit.app.VCSConnectionCommit(
                                        author_email = '', 
                                        author_name = '', 
                                        component_config_connection_id = '', 
                                        created_at = '', 
                                        created_by_id = '', 
                                        id = '', 
                                        message = '', 
                                        sha = '', 
                                        updated_at = '', )
                                    ], ), 
                            vcs_connection_id = '', ), 
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        org_id = '', 
                        public_git_vcs_config = nuon.models.app/public_git_vcs_config.app.PublicGitVCSConfig(
                            branch = '', 
                            component_config_id = '', 
                            component_config_type = '', 
                            created_at = '', 
                            created_by_id = '', 
                            directory = '', 
                            id = '', 
                            repo = '', 
                            updated_at = '', ), 
                        sandbox_release = nuon.models.app/sandbox_release.app.SandboxRelease(
                            created_at = '', 
                            created_by_id = '', 
                            deprovision_policy_url = '', 
                            id = '', 
                            one_click_role_template_url = '', 
                            provision_policy_url = '', 
                            trust_policy_url = '', 
                            updated_at = '', 
                            version = '', ), 
                        sandbox_release_id = '', 
                        terraform_version = '', 
                        updated_at = '', 
                        variables = {
                            'key' : ''
                            }, ), 
                    aws_account = nuon.models.app/aws_account.app.AWSAccount(
                        created_at = '', 
                        created_by_id = '', 
                        iam_role_arn = '', 
                        id = '', 
                        region = '', 
                        updated_at = '', ), 
                    azure_account = nuon.models.app/azure_account.app.AzureAccount(
                        created_at = '', 
                        created_by_id = '', 
                        id = '', 
                        install = nuon.models.app/install.app.Install(
                            app_id = '', 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            install_components = [
                                nuon.models.app/install_component.app.InstallComponent(
                                    component = nuon.models.app/component.app.Component(
                                        app_id = '', 
                                        config_versions = 56, 
                                        created_at = '', 
                                        created_by_id = '', 
                                        dependencies = [
                                            ''
                                            ], 
                                        id = '', 
                                        name = '', 
                                        status = '', 
                                        status_description = '', 
                                        updated_at = '', ), 
                                    component_id = '', 
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    install_deploys = [
                                        nuon.models.app/install_deploy.app.InstallDeploy(
                                            build_id = '', 
                                            component_id = '', 
                                            component_name = '', 
                                            created_at = '', 
                                            created_by_id = '', 
                                            id = '', 
                                            install_component_id = '', 
                                            install_deploy_type = 'release', 
                                            install_id = '', 
                                            release_id = '', 
                                            status = '', 
                                            status_description = '', 
                                            updated_at = '', )
                                        ], 
                                    install_id = '', 
                                    updated_at = '', )
                                ], 
                            install_events = [
                                nuon.models.app/install_event.app.InstallEvent(
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    install_id = '', 
                                    operation = 'provision', 
                                    operation_name = '', 
                                    operation_status = 'started', 
                                    org_id = '', 
                                    payload = {
                                        'key' : ''
                                        }, 
                                    updated_at = '', )
                                ], 
                            install_inputs = [
                                nuon.models.app/install_inputs.app.InstallInputs(
                                    app_input_config_id = '', 
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    install_id = '', 
                                    org_id = '', 
                                    updated_at = '', 
                                    values = {
                                        'key' : ''
                                        }, )
                                ], 
                            install_sandbox_runs = [
                                nuon.models.app/install_sandbox_run.app.InstallSandboxRun(
                                    created_at = '', 
                                    created_by_id = '', 
                                    id = '', 
                                    install_id = '', 
                                    run_type = 'provision', 
                                    status = '', 
                                    status_description = '', 
                                    updated_at = '', )
                                ], 
                            name = '', 
                            status = '', 
                            status_description = '', 
                            updated_at = '', ), 
                        location = '', 
                        service_principal_app_id = '', 
                        service_principal_password = '', 
                        subscription_id = '', 
                        subscription_tenant_id = '', 
                        updated_at = '', ), 
                    created_at = '', 
                    created_by = nuon.models.app/user_token.app.UserToken(
                        created_at = '', 
                        created_by_id = '', 
                        email = '', 
                        expires_at = '', 
                        id = '', 
                        issued_at = '', 
                        issuer = '', 
                        subject = '', 
                        updated_at = '', ), 
                    created_by_id = '', 
                    id = '', 
                    install_components = [
                        nuon.models.app/install_component.app.InstallComponent(
                            component_id = '', 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            install_id = '', 
                            updated_at = '', )
                        ], 
                    install_events = [
                        nuon.models.app/install_event.app.InstallEvent(
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            install_id = '', 
                            operation_name = '', 
                            org_id = '', 
                            updated_at = '', )
                        ], 
                    install_inputs = [
                        nuon.models.app/install_inputs.app.InstallInputs(
                            app_input_config_id = '', 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            install_id = '', 
                            org_id = '', 
                            updated_at = '', )
                        ], 
                    install_sandbox_runs = [
                        nuon.models.app/install_sandbox_run.app.InstallSandboxRun(
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            install_id = '', 
                            status = '', 
                            status_description = '', 
                            updated_at = '', )
                        ], 
                    name = '', 
                    status = '', 
                    status_description = '', 
                    updated_at = '', ),
                location = '',
                service_principal_app_id = '',
                service_principal_password = '',
                subscription_id = '',
                subscription_tenant_id = '',
                updated_at = ''
            )
        else:
            return AppAzureAccount(
        )
        """

    def testAppAzureAccount(self):
        """Test AppAzureAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.15
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from nuon.api.installs_api import InstallsApi


class TestInstallsApi(unittest.TestCase):
    """InstallsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InstallsApi()

    def tearDown(self) -> None:
        pass

    def test_create_install(self) -> None:
        """Test case for create_install

        create an app install
        """
        pass

    def test_create_install_deploy(self) -> None:
        """Test case for create_install_deploy

        deploy a build to an install
        """
        pass

    def test_create_install_inputs(self) -> None:
        """Test case for create_install_inputs

        create install inputs
        """
        pass

    def test_delete_install(self) -> None:
        """Test case for delete_install

        delete an install
        """
        pass

    def test_get_app_installs(self) -> None:
        """Test case for get_app_installs

        get all installs for an app
        """
        pass

    def test_get_current_install_inputs(self) -> None:
        """Test case for get_current_install_inputs

        get an installs current inputs
        """
        pass

    def test_get_install(self) -> None:
        """Test case for get_install

        get an install
        """
        pass

    def test_get_install_component(self) -> None:
        """Test case for get_install_component

        get an install component
        """
        pass

    def test_get_install_component_deploys(self) -> None:
        """Test case for get_install_component_deploys

        get an install components deploys
        """
        pass

    def test_get_install_component_latest_deploy(self) -> None:
        """Test case for get_install_component_latest_deploy

        get the latest deploy for an install component
        """
        pass

    def test_get_install_components(self) -> None:
        """Test case for get_install_components

        get an installs components
        """
        pass

    def test_get_install_deploy(self) -> None:
        """Test case for get_install_deploy

        get an install deploy
        """
        pass

    def test_get_install_deploy_logs(self) -> None:
        """Test case for get_install_deploy_logs

        get install deploy logs
        """
        pass

    def test_get_install_deploy_plan(self) -> None:
        """Test case for get_install_deploy_plan

        get install deploy plan
        """
        pass

    def test_get_install_deploys(self) -> None:
        """Test case for get_install_deploys

        get all deploys to an install
        """
        pass

    def test_get_install_inputs(self) -> None:
        """Test case for get_install_inputs

        get an installs inputs
        """
        pass

    def test_get_install_latest_deploy(self) -> None:
        """Test case for get_install_latest_deploy

        get an install deploy
        """
        pass

    def test_get_install_sandbox_run_logs(self) -> None:
        """Test case for get_install_sandbox_run_logs

        get install sandbox run logs
        """
        pass

    def test_get_install_sandbox_runs(self) -> None:
        """Test case for get_install_sandbox_runs

        get an installs sandbox runs
        """
        pass

    def test_get_org_installs(self) -> None:
        """Test case for get_org_installs

        get all installs for an org
        """
        pass

    def test_installer_create_installer(self) -> None:
        """Test case for installer_create_installer

        create an app install from an installer
        """
        pass

    def test_installer_get_install(self) -> None:
        """Test case for installer_get_install

        get an installer install
        """
        pass

    def test_teardown_install_component(self) -> None:
        """Test case for teardown_install_component

        teardown an install component
        """
        pass

    def test_update_install(self) -> None:
        """Test case for update_install

        update an install
        """
        pass


if __name__ == '__main__':
    unittest.main()
